### Appearance

The “Appearance” section defines the visual appearance of Font View and Edit View.

“Display Unicode Value” controls whether glyphs with Unicode values show a simplified Unicode icon or display the code point in the bottom-right of the glyph cell.

“Always use Light Mode” is available for both Font View and Edit View.
These options allow Glyphs to run using the dark appearance of the system (configurable from System Settings) while still displaying the window content with a light appearance.

“Text View Width” controls the line length of text in Edit View.
The value is measured in thousandths of an em.
It is independent of the units per em (UPM) of the font.

“Handle size” controls the size of the points, such as on-curve nodes, control handles, and anchors.
Smaller sizes present a cleaner user interface; larger sizes are easier to see and click-select.

“Display Mark Cloud” shows a superimposition of the combining marks of a glyph.
A “mark cloud” appears for all glyphs when an anchor is selected.
The glyph info database defines the marks shown for a glyph and its anchors.

Disable this option to suppress the display of mark clouds.

Various colors can be configured for both the light and the dark system appearance.
Available customization options are the color of corner nodes ,
smooth nodes ,
alignment zones ,
the color of strokes on the foreground layer ,
the background layer ,
and other layers  (made visible by clicking on the eye / icon in the layers list),
the color of the Edit View canvas,
and the kerning indicator colors (by default light blue  for negative kerning and yellow  for positive kerning).
Clicking the “Standard” button resets all colors to their default values.